@@ -11,8 +11,7 @@ class ConfigParser:
     NO_URL = 0
     URL_INTERNAL = 1
     URL_EXTERNAL = 2
-    URL_METHOD = 3
-    URL_PK = 4
+    URL_CALL = 3
 
     def __init__(self):
         self.list_configuration = dict(
@@ -26,11 +25,6 @@ class ConfigParser:
 
     def configure(self, configuration):
         if 'list' in configuration.keys():
-            if 'pk' not in configuration['list'].keys():
-                raise ConfigurationError('Not set list pk element')
-
-            self.parse_list_pk(configuration['list']['pk'])
-
             if 'display' in configuration['list'].keys():
                 self.parse_list_display(configuration['list']['display'])
 
@@ -46,12 +40,6 @@ class ConfigParser:
             if 'filter' in configuration['list'].keys():
                 self.parse_filter(configuration['list']['filter'])
 
-    def parse_list_pk(self, pk):
-        if 'key' not in pk:
-            raise ConfigurationError('Wrong configuration format for key pk element')
-
-        self.list_configuration['pk'] = pk
-
     def parse_list_display(self, elements):
         for element in elements:
             if not all(k in element for k in ('key', 'label')):
@@ -145,6 +133,7 @@ class ConfigParser:
                 pre['form'] = Form()
 
             if pre['call'] and call_object is not None:
+                pre['type'] = self.URL_CALL
                 pre = getattr(call_object, pre['call'])(pre)
 
             yield pre
